@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -177,6 +177,8 @@ link_set_ui (GtkHTMLEditLinkProperties *d)
 		
 			gtk_entry_set_text (GTK_ENTRY (d->entry_url), "http://");
 		}
+
+		g_free (url);
 	}
 
 	d->disable_change = FALSE;
