@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef _HTMLRULE_H_
@@ -24,9 +24,6 @@
 
 #include "htmlobject.h"
 
-typedef struct _HTMLRule HTMLRule;
-typedef struct _HTMLRuleClass HTMLRuleClass;
-
 #define HTML_RULE(x) ((HTMLRule *) (x))
 #define HTML_RULE_CLASS(x) ((HTMLRuleClass *) (x))
 
