@@ -18,8 +18,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 /* The HTML Tokenizer */
@@ -89,6 +89,7 @@ struct _HTMLTokenizerPrivate {
 	gboolean select; /* Are we in a <select> block? */
 	gboolean charEntity; /* Are we in an &... sequence? */
 	gboolean extension; /* Are we in an <!-- +GtkHTML: sequence? */
+	gboolean aTag; /* Are we in a <a/> tag*/
  
 	enum {
 		NoneDiscard = 0,
@@ -233,6 +234,7 @@ html_tokenizer_init (HTMLTokenizer *t)
 	p->select = FALSE;
 	p->charEntity = FALSE;
 	p->extension = FALSE;
+	p->aTag = FALSE;
 
 	p->discard = NoneDiscard;
 	p->pending = NonePending;
@@ -732,12 +734,30 @@ in_script_or_style (HTMLTokenizer *t, const gchar **src)
 	}
 	/* Check if a </script> tag is on its way */
 	else if (p->searchCount > 0) {
+		gboolean put_to_script = FALSE;
 		if (tolower (**src) == p->searchFor [p->searchCount]) {
 			p->searchBuffer [p->searchCount] = **src;
 			p->searchCount++;
 			(*src)++;
 		}
-		else {
+		else if (p->searchFor [p->searchCount] == '>') {
+			/* There can be any number of white-space characters between
+			   tag name and closing '>' so try to move through them, if possible */
+
+			const gchar **p = src;
+			while (isspace (**p))
+				(*p)++;
+
+			
+			if (**p == '>')
+				*src = *p;
+			else
+				put_to_script = TRUE;
+		}
+		else 
+			put_to_script = TRUE;
+
+		if (put_to_script) {
 			gchar *c;
 
 			p->searchBuffer [p->searchCount] = 0;
@@ -1048,6 +1068,7 @@ end_tag (HTMLTokenizer *t, const gchar **src)
 	p->dest = p->buffer;
 			
 	p->tag = FALSE;
+	p->aTag = FALSE;
 	p->pending = NonePending;
 	(*src)++;
 			
@@ -1150,6 +1171,8 @@ in_crlf (HTMLTokenizer *t, const gchar **src)
 static void
 in_space_or_tab (HTMLTokenizer *t, const gchar **src)
 {
+	gchar *ptr;
+	
 	if (t->priv->tquote) {
 		if (t->priv->discard == NoneDiscard)
 			t->priv->pending = SpacePending;
@@ -1158,6 +1181,9 @@ in_space_or_tab (HTMLTokenizer *t, const gchar **src)
 		t->priv->searchCount = 0; /* Stop looking for <!-- sequence */
 		if (t->priv->discard == NoneDiscard)
 			t->priv->pending = SpacePending;
+		ptr = t->priv->buffer;
+		if (strlen (ptr) == 3 && ptr[1] == '<' && ptr[2] == 'a')
+			t->priv->aTag = TRUE;
 	}
 	else if (t->priv->pre || t->priv->textarea) {
 		if (t->priv->pending)
@@ -1287,7 +1313,7 @@ html_tokenizer_tokenize_one_char (HTMLTokenizer *t, const gchar **src)
 		in_entity (t, src);
 	else if (p->startTag)
 		in_tag (t, src);
-	else if (**src == '&')
+	else if (**src == '&' && !p->aTag)
 		start_entity (t, src);
 	else if (**src == '<' && !p->tag)
 		start_tag (t, src);
